<?php
/**
 * lithium functions and definitions
 *
 * @package lithium
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 750; /* pixels */

if ( ! function_exists( 'lithium_setup' ) ) :
/**
 * Set up theme defaults and register support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function lithium_setup() {
    global $cap, $content_width;

    // This theme styles the visual editor with editor-style.css to match the theme style.
    add_editor_style();


		/**
		 * Add default posts and comments RSS feed links to head
		*/
		add_theme_support( 'automatic-feed-links' );
		
		/**
		 * Enable support for Post Thumbnails on posts and pages
		 *
		 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		*/
		add_theme_support( 'post-thumbnails' );
		
		/**
		 * Enable support for Post Formats
		*/
		add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
		
		/**
		 * Setup the WordPress core custom background feature.
		*/
		add_theme_support( 'custom-background', apply_filters( 'lithium_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );
	

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on lithium, use a find and replace
	 * to change 'lithium' to the name of your theme in all the template files
	*/
	load_theme_textdomain( 'lithium', get_template_directory() . '/languages' );

	/**
	 * This theme uses wp_nav_menu() in one location.
	*/ 
    register_nav_menus( array(
        'primary'  => __( 'Header bottom menu', 'lithium' ),
    ) );

}
endif; // lithium_setup
add_action( 'after_setup_theme', 'lithium_setup' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function lithium_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'lithium' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'lithium_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function lithium_scripts() {
	wp_enqueue_style( 'lithium-style', get_stylesheet_uri() );

	// load bootstrap css
	wp_enqueue_style( 'lithium-bootstrap', get_template_directory_uri() . '/includes/resources/bootstrap/css/bootstrap.min.css' );
	
	// load bootstrap js
	wp_enqueue_script('lithium-bootstrapjs', get_template_directory_uri().'/includes/resources/bootstrap/js/bootstrap.min.js', array('jquery') );

	// load the glyphicons
	wp_enqueue_style( 'lithium-glyphicons', get_template_directory_uri() . '/includes/resources/glyphicons/css/bootstrap-glyphicons.css' );
		
	// load bootstrap wp js
	wp_enqueue_script( 'lithium-bootstrapwp', get_template_directory_uri() . '/includes/js/bootstrap-wp.js', array('jquery') );

	wp_enqueue_script( 'lithium-skip-link-focus-fix', get_template_directory_uri() . '/includes/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'lithium-keyboard-image-navigation', get_template_directory_uri() . '/includes/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
}
add_action( 'wp_enqueue_scripts', 'lithium_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/includes/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/includes/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/includes/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/includes/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/includes/jetpack.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/includes/bootstrap-wp-navwalker.php';

/**
 * Load The Theme Option Page.
 */
require get_template_directory() . '/includes/theme-options.php';

/**
 * Load The Social widget.
 */
require get_template_directory() . '/includes/social-widget.php';

/**
 * Load The Social widget.
 */
require get_template_directory() . '/includes/video-widget.php';

/**
 * Load The Social widget.
 */
require get_template_directory() . '/video-post.php';

/**
 * Load The Flickr Widget.
 */
require get_template_directory() . '/includes/quick_flickr_widget.php';



/* Custom Excerpt */
function lithium_excerpt($limit) {
 $excerpt = explode(' ', get_the_content(), $limit);
 if (count($excerpt)>=$limit) {
 array_pop($excerpt);
 $excerpt = implode(" ",$excerpt).'...';
 } else {
 $excerpt = implode(" ",$excerpt);
 }
 $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
 return $excerpt;
}

function content($limit) {
 $content = explode(' ', get_the_content(), $limit);
 if (count($content)>=$limit) {
 array_pop($content);
 $content = implode(" ",$content).'...';
 } else {
 $content = implode(" ",$content);
 }
 $content = preg_replace('/[.+]/','', $content);
 $content = apply_filters('the_content', $content);
 $content = str_replace(']]>', ']]&gt;', $content);
 return $content;
}




/* Includes
--------------------------------------------------- */
/**
 * Load The Flickr Widget.
 */
require get_template_directory() . '/sbincludes/scripts.php';
//include_once ('sbincludess/scripts.php');


/* Create & Display Widget
--------------------------------------------------- */

class sb_tabbed_widget extends WP_Widget {
 
    /** constructor */
    function sb_tabbed_widget() {
        parent::WP_Widget(false, $name = 'SB Popular Posts Tabbed Widget');	
    }
 
    /** @see WP_Widget::widget */
	function widget($args, $instance) {
		extract( $args );
		$number 	= $instance['number']; // Number of posts to show
		$checkbox   = $instance['checkbox']; // Show post thumbnails
		$checkbox2  = $instance['checkbox2']; // Show post meta

		?>

			  <?php echo $before_widget; ?>
				  
				  <div class="sb_tabbed">
				  	<!-- The tabs -->
				  	<ul class="sb_tabs">
				  		<li class="t1"><a class="t1 tab" title="Tab 1"><?php echo 'Popular'; ?></a></li>
				  		<li class="t2"><a class="t2 tab" title="Tab 2"><?php echo 'Recent'; ?></a></li>
				  		<li class="t3"><a class="t3 tab" title="Tab 3"><?php echo 'Categories'; ?></a></li>
				  	</ul>
				  
				  	<!-- tab 1 -->
				  	<div class="tab-content t1">

				  	<ul>
				  	<?php
				  	$sb_pop_posts_query = new WP_Query( array ( 'orderby' => 'comment_count', 'order' => 'DESC', 'posts_per_page' => $number, 'post__not_in' => get_option( 'sticky_posts' ) ) );
				  	
					  	if($sb_pop_posts_query->have_posts()):
						while($sb_pop_posts_query->have_posts()):
					  	$sb_pop_posts_query->the_post();
					  	
					 ?>
					 
					 <li>

					 	<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
						 	<?php if ( has_post_thumbnail() && $checkbox == true ) { the_post_thumbnail( array(50,50), array('class' => 'alignleft') ); } elseif ( !has_post_thumbnail() && $checkbox == true ) { ?> <img src="<?php echo get_template_directory_uri() ?>sbincludes/images/default-thumb.png" alt="<?php the_title(); ?>" class="alignleft" width="50" height="50" /> <?php } ?>
						 	<?php echo get_the_title(); ?>
					 
						 </a>
						 
						 <?php if ( $checkbox2 == true ) { ?> 
						 <span class="sb-comment-meta"><?php echo comments_number( '', '1 Comment', '% Comments' ); ?></span>
						 <?php } ?>
					 
					 </li>
				  	
				  	<?php endwhile;
				  		  endif;
				  		  /* Restore original Post Data */
				  		  wp_reset_postdata();
				    ?>
				  	</ul>
				  	
				  	</div>
				  
				  	<!-- tab 2 -->
				  	<div class="tab-content t2">
				  	
				  	<ul>
				  	<?php
				  	$sb_recent_posts_query = new WP_Query( array ( 'posts_per_page' => $number ) );
				  	
					  	if($sb_recent_posts_query->have_posts()):
						while($sb_recent_posts_query->have_posts()):
					  	$sb_recent_posts_query->the_post();
					  	
					 ?>
					 
					 <li>
					 
					 	<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
					 	
					 		<?php if ( has_post_thumbnail() && $checkbox == true ) { the_post_thumbnail( array(50,50), array('class' => 'alignleft') ); } elseif ( !has_post_thumbnail() && $checkbox == true ) { ?> <img src="<?php echo get_template_directory_uri() ?>sbincludes/images/default-thumb.png" alt="<?php the_title(); ?>" class="alignleft" width="50" height="50" /> <?php } ?>
					 
						 	<?php the_title(); ?>
					 
						 </a>
						 
						  <?php if ( $checkbox2 == true ) { ?> 
						  <span class="sb-date-meta"><?php the_date(); ?></span>
						  <?php } ?>
					 
					 </li>
				  	
				  	<?php endwhile;
				  		  endif; 
				  		  /* Restore original Post Data */
				  		  wp_reset_postdata();
				    ?>
				  	</ul>
				  	
				  	</div>
				  
				  	<!-- tab 3 -->
				  	<div class="tab-content t3">
				  	
				  		<ul>
		    			<?php 
		    			
		    			$cat_args=array(
						'orderby' => 'name',
						'order' => 'ASC',
						'number' => $number
						);
						$categories=get_categories($cat_args);
						
						foreach($categories as $category) { 
						  echo '<li><a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( "View all posts in %s", $category->name ) . '" ' . '>' . $category->name.'</a>';
						  if ( $checkbox2 == true ) { 
							  echo '<span class="sb-cat-meta"> (' . $category->count . ')</span></li>';
						     } else { echo '</li>'; }
						  }
						?>	
		    			</ul>
				  	</div>
				  
				  </div><!-- tabbed -->

			  <?php echo $after_widget; ?>
		<?php
	}
	

/* Update @see WP_Widget::update
--------------------------------------------------- */

	function update($new_instance, $old_instance) {
		$instance = $old_instance;

		$instance['number'] = wp_kses_data($new_instance['number']);
		$instance['checkbox'] = strip_tags($new_instance['checkbox']);
		$instance['checkbox2'] = strip_tags($new_instance['checkbox2']);
		return $instance;
	}

/* Widget Options @see WP_Widget::form
--------------------------------------------------- */ 
    
	function form($instance) {
		$defaults = array(
			'number'	=> 5,
			'checkbox'	=> true,
			'checkbox2'	=> true,
		);
		extract( wp_parse_args( $instance, $defaults ) );
		
		?>
		<p>
		  <label for="<?php echo $this->get_field_id('number'); ?>"><?php echo 'Number of posts to display:'; ?></label>
		  <input size="2" id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
		</p>
		<p>
		<input id="<?php echo $this->get_field_id('checkbox'); ?>" name="<?php echo $this->get_field_name('checkbox'); ?>" type="checkbox" value="1" <?php checked( '1', $checkbox ); ?>/>
        <label for="<?php echo $this->get_field_id('checkbox'); ?>"><?php echo 'Display thumbnails'; ?></label>
		</p>
		<p>
		<input id="<?php echo $this->get_field_id('checkbox2'); ?>" name="<?php echo $this->get_field_name('checkbox2'); ?>" type="checkbox" value="1" <?php checked( '1', $checkbox2 ); ?>/>
        <label for="<?php echo $this->get_field_id('checkbox2'); ?>"><?php echo 'Display meta (date, comments)'; ?></label>
		</p>
		<?php
	}
	
}

add_action('widgets_init', create_function('', 'return register_widget("sb_tabbed_widget");'));