<?php

add_action( 'admin_init', 'theme_options_init' );
add_action( 'admin_menu', 'theme_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function theme_options_init(){
	register_setting( 'sample_options', 'lithium_options', 'theme_options_validate' );
}

/**
 * Load up the menu page
 */
function theme_options_add_page() {
	add_theme_page( __( 'Theme Options', 'lithium' ), __( 'Theme Options', 'lithium' ), 'edit_theme_options', 'theme_options', 'theme_options_do_page' );
}

/**
 * Create the options page
 */
function theme_options_do_page() {
	global $select_options, $radio_options;

	if ( ! isset( $_REQUEST['settings-updated'] ) )
		$_REQUEST['settings-updated'] = false;

	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" .' Theme Options'. "</h2>"; ?>

		<?php if ( false !== $_REQUEST['settings-updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved', 'lithium' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'sample_options' ); ?>
			<?php $lithiumoptions = get_option( 'lithium_options' ); ?>

			<table class="form-table">

				<?php
				/**
				 * A sample text input option
				 */
				?>
				<tr valign="top"><th scope="row"><?php echo 'Twitter'; ?></th>
					<td>
						<input id="lithium_options[twitterurl]" class="regular-text" type="text" name="lithium_options[twitterurl]" value="<?php echo $lithiumoptions['twitterurl']; ?>" />
						<label class="description" for="lithium_options[twitterurl]"><?php _e( 'Give the Twitter URL', 'lithium' ); ?></label>
					</td>
				</tr>
				<tr valign="top"><th scope="row"><?php echo'Facebook'; ?></th>
					<td>
						<input id="lithium_options[facebookurl]" class="regular-text" type="text" name="lithium_options[facebookurl]" value="<?php echo $lithiumoptions['facebookurl']; ?>" />
						<label class="description" for="lithium_options[facebookurl]"><?php _e( 'Give the Facebook URL', 'lithium' ); ?></label>
					</td>
				</tr>
				<tr valign="top"><th scope="row"><?php echo 'Google+'; ?></th>
					<td>
						<input id="lithium_options[googleurl]" class="regular-text" type="text" name="lithium_options[googleurl]" value="<?php echo $lithiumoptions['googleurl']; ?>" />
						<label class="description" for="lithium_options[googleurl]"><?php _e( 'Give the Google+ URL', 'lithium' ); ?></label>
					</td>
				</tr>
				<tr valign="top"><th scope="row"><?php echo 'Pinterest'; ?></th>
					<td>
						<input id="lithium_options[pinteresturl]" class="regular-text" type="text" name="lithium_options[pinteresturl]" value="<?php echo $lithiumoptions['pinteresturl']; ?>" />
						<label class="description" for="lithium_options[pinteresturl]"><?php _e( 'Give the Pinterest URL', 'lithium' ); ?></label>
					</td>
				</tr>
				<tr valign="top"><th scope="row"><?php echo 'Flicker'; ?></th>
					<td>
						<input id="lithium_options[flickerurl]" class="regular-text" type="text" name="lithium_options[flickerurl]" value="<?php echo $lithiumoptions['flickerurl']; ?>" />
						<label class="description" for="lithium_options[flickerurl]"><?php _e( 'Give the Flicker URL', 'lithium' ); ?></label>
					</td>
				</tr>
				<tr valign="top"><th scope="row"><?php echo 'Instagram'; ?></th>
					<td>
						<input id="lithium_options[instagramurl]" class="regular-text" type="text" name="lithium_options[instagramurl]" value="<?php echo $lithiumoptions['instagramurl']; ?>" />
						<label class="description" for="lithium_options[instagramurl]"><?php _e( 'Give the Instagram URL', 'lithium' ); ?></label>
					</td>
				</tr>
			</table>

			<p class="submit">
				<input type="submit" class="button-primary" value="<?php echo 'Save Options'; ?>" />
			</p>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function theme_options_validate( $input ) {
	global $select_options, $radio_options;

	// Our checkbox value is either 0 or 1
	if ( ! isset( $input['option1'] ) )
		$input['option1'] = null;
	$input['option1'] = ( $input['option1'] == 1 ? 1 : 0 );

	// Say our text option must be safe text with no HTML tags
	$input['sometext'] = wp_filter_nohtml_kses( $input['sometext'] );

	// Our select option must actually be in our array of select options
	if ( ! array_key_exists( $input['selectinput'], $select_options ) )
		$input['selectinput'] = null;

	// Our radio option must actually be in our array of radio options
	if ( ! isset( $input['radioinput'] ) )
		$input['radioinput'] = null;
	if ( ! array_key_exists( $input['radioinput'], $radio_options ) )
		$input['radioinput'] = null;

	// Say our textarea option must be safe text with the allowed tags for posts
	$input['sometextarea'] = wp_filter_post_kses( $input['sometextarea'] );

	return $input;
}

